@@ -152,11 +152,14 @@ class ChunksWidget(QWidget):
             mtime = self.mtime
         else:
             return
-        if os.path.exists(path):
-            newmtime = os.path.getmtime(path)
-            if mtime != newmtime:
-                self.mtime = newmtime
-                self.refresh()
+        try:
+            if os.path.exists(path):
+                newmtime = os.path.getmtime(path)
+                if mtime != newmtime:
+                    self.mtime = newmtime
+                    self.refresh()
+        except EnvironmentError:
+            pass
 
     def runPatcher(self, fp, wfile, updatestate):
         ui = self.repo.ui.copy()
@@ -259,7 +262,7 @@ class ChunksWidget(QWidget):
                         for chunk in ctx._files[wfile]:
                             chunk.write(buf)
                 fp.write(buf.getvalue())
-                fp.rename()
+                fp.close()
             finally:
                 del fp
             ctx.invalidate()
@@ -338,7 +341,7 @@ class ChunksWidget(QWidget):
                 for file in ctx._fileorder:
                     for chunk in ctx._files[file]:
                         chunk.write(fp)
-                fp.rename()
+                fp.close()
                 ctx.invalidate()
                 self.fileModified.emit()
                 return True
@@ -377,7 +380,7 @@ class ChunksWidget(QWidget):
                         continue
                     for chunk in ctx._files[file]:
                         chunk.write(fp)
-                fp.rename()
+                fp.close()
             finally:
                 del fp
             ctx.invalidate()
