@@ -12,7 +12,7 @@ from mercurial import util
 
 from tortoisehg.util import hglib, shlib
 from tortoisehg.hgqt.i18n import _
-from tortoisehg.hgqt import qtlib, status, cmdui
+from tortoisehg.hgqt import qtlib, status, cmdui, lfprompt
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
@@ -107,6 +107,17 @@ class QuickOpDialog(QDialog):
         hbox.addWidget(bb)
         toplayout.addLayout(hbox)
         self.bb = bb
+        
+        if self.command == 'add':
+            if 'largefiles' in self.repo.extensions():
+                self.addLfilesButton = QPushButton(_('Add &Largefiles'))
+            elif 'kbfiles' in self.repo.extensions():
+                self.addLfilesButton = QPushButton(_("Add &Bfiles"))
+            else:
+                self.addLfilesButton = None
+            if self.addLfilesButton:
+                self.addLfilesButton.clicked.connect(self.addLfiles)
+                bb.addButton(self.addLfilesButton, BB.ActionRole)
 
         layout.addWidget(self.statusbar)
 
@@ -147,9 +158,14 @@ class QuickOpDialog(QDialog):
                                 _('No operation to perform'),
                                 parent=self)
             return
+        self.repo.bfstatus = True
+        self.repo.lfstatus = True
+        repostate = self.repo.status()
+        self.repo.bfstatus = False
+        self.repo.lfstatus = False
         if self.command == 'remove':
             if not self.chk.isChecked():
-                modified = self.repo.status()[0]
+                modified = repostate[0]
                 selmodified = []
                 for wfile in files:
                     if wfile in modified:
@@ -167,14 +183,18 @@ class QuickOpDialog(QDialog):
                         cmdline.append('--force')
                     elif ret == 2:
                         return
-            wctx = self.repo[None]
+            unknown, ignored = repostate[4:6]
             for wfile in files:
-                if wfile not in wctx:
+                if wfile in unknown or wfile in ignored:
                     try:
                         util.unlink(wfile)
                     except EnvironmentError:
                         pass
                     files.remove(wfile)
+        elif self.command == 'add':
+            if 'largefiles' in self.repo.extensions() or 'kbfiles' in self.repo.extensions():
+                self.addWithPrompt(files)
+                return
         if files:
             cmdline.extend(files)
             self.files = files
@@ -198,6 +218,40 @@ class QuickOpDialog(QDialog):
                     s.setValue('quickop/forceremove', self.chk.isChecked())
             QDialog.reject(self)
 
+    def addLfiles(self):
+        if 'kbfiles' in self.repo.extensions():
+            cmdline = ['add', '--bf']
+        else:
+            cmdline = ['add', '--large']
+        files = self.stwidget.getChecked()
+        if not files:
+            qtlib.WarningMsgBox(_('No files selected'),
+                                _('No operation to perform'),
+                                parent=self)
+            return
+        cmdline.extend(files)
+        self.files = files
+        self.cmd.run(cmdline)
+
+    def addWithPrompt(self, files):
+        result = lfprompt.promptForLfiles(self, self.repo.ui, self.repo, files,
+                                          'kbfiles' in self.repo.extensions())
+        if not result:
+            return
+        files, bfiles = result
+        if files:
+            cmdline = ['add']
+            cmdline.extend(files)
+            self.files = files
+            self.cmd.run(cmdline)
+        if bfiles:
+            if 'kbfiles' in self.repo.extensions():
+                cmdline = ['add', '--bf']
+            else:
+                cmdline = ['add', '--large']
+            cmdline.extend(bfiles)
+            self.files = bfiles
+            self.cmd.run(cmdline)
 
 instance = None
 class HeadlessQuickop(QWidget):
