@@ -7,7 +7,7 @@
 
 import os
 
-from mercurial import ui, util, error
+from mercurial import ui, util, error, extensions
 
 from tortoisehg.util import hglib, settings, paths, wconfig, i18n, bugtraq
 from tortoisehg.hgqt.i18n import _
@@ -24,6 +24,12 @@ from PyQt4.QtGui import *
 _unspecstr = _('<unspecified>')
 ENTRY_WIDTH = 300
 
+def hasExtension(extname):
+    for name, module in extensions.extensions():
+        if name == extname:
+            return True
+    return False
+
 class SettingsCombo(QComboBox):
     def __init__(self, parent=None, **opts):
         QComboBox.__init__(self, parent, toolTip=opts['tooltip'])
@@ -315,6 +321,46 @@ class BugTraqConfigureEntry(QPushButton):
         return self.value() != self.curvalue
 
 
+class PathBrowser(QWidget):
+    def __init__(self, parent=None, **opts):
+        QWidget.__init__(self, parent, toolTip=opts['tooltip'])
+        self.opts = opts
+        
+        self.lineEdit = QLineEdit()
+        completer = QCompleter(self)
+        completer.setModel(QDirModel(completer))
+        self.lineEdit.setCompleter(completer)
+        
+        self.browseButton = QPushButton(_('&Browse...'))
+        self.browseButton.clicked.connect(self.browse)
+        
+        layout = QHBoxLayout()
+        layout.setContentsMargins(0, 0, 0, 0)
+        layout.addWidget(self.lineEdit)
+        layout.addWidget(self.browseButton)
+        self.setLayout(layout)
+        
+    def browse(self):
+        dir = QFileDialog.getExistingDirectory(self, directory=self.lineEdit.text(),
+                                               options=QFileDialog.ShowDirsOnly)
+        if dir:
+            self.lineEdit.setText(dir)
+    
+    ## common APIs for all edit widgets
+    def setValue(self, curvalue):
+        self.curvalue = curvalue
+        if curvalue:
+            self.lineEdit.setText(hglib.tounicode(curvalue))
+        else:
+            self.lineEdit.setText('')
+            
+    def value(self):
+        utext = self.lineEdit.text()
+        return utext and hglib.fromunicode(utext) or None
+    
+    def isDirty(self):
+        return self.value() != self.curvalue
+        
 def genEditCombo(opts, defaults=[]):
     opts['canedit'] = True
     opts['defaults'] = defaults
@@ -352,6 +398,9 @@ def genFontEdit(opts):
 def genBugTraqEdit(opts):
     return BugTraqConfigureEntry(**opts)
 
+def genPathBrowser(opts):
+    return PathBrowser(**opts)
+
 def findIssueTrackerPlugins():
     plugins = bugtraq.get_issue_plugins_with_names()
     names = [("%s %s" % (key[0], key[1])) for key in plugins]
@@ -480,6 +529,11 @@ INFO = (
         'repository.  You can select the "current" (i.e. the working directory '
         'parent), the current "tip" or the working directory ("workingdir"). '
         'Default: current')),
+    _fi(_('Open new tabs next\nto the current tab'),
+        'tortoisehg.opentabsaftercurrent', genBoolRBGroup,
+        _('Should new tabs be open next to the current tab? '
+        'If False new tabs will be open after the last tab. '
+        'Default: True')),
     _fi(_('Author Coloring'), 'tortoisehg.authorcolor', genBoolRBGroup,
         _('Color changesets by author name.  If not enabled, '
           'the changes are colored green for merge, red for '
@@ -549,6 +603,22 @@ INFO = (
          'environment variables are set to a non-English language. '
          'This setting is used by the Merge, Tag and Backout dialogs. '
          'Default: False')),
+    _fi(_('Monitor working<br>directory changes'),
+        'tortoisehg.refreshwdstatus',
+        (genDefaultCombo,
+        ['auto', 'always', 'alwayslocal']),
+        _('Select when the working directory status list will be refreshed:<br>'
+        '- <b>auto</b>: [<i>default</i>] let TortoiseHg decide when to refresh the working '
+        'directory status list.<br>'
+        'TortoiseHg will refresh the status list whenever it performs an action '
+        'that may potentially modify the working directory. <i>This may miss '
+        'any changes that happen outside of TortoiseHg\'s control;</i><br>'
+        '- <b>always</b>: in addition to the automatic updates above, also '
+        'refresh the status list whenever the user clicks on the "working dir '
+        'revision" or on the "Commit icon" on the workbench task bar;<br>'
+        '- <b>alwayslocal</b>: same as "<b>always</b>" but restricts forced '
+        'refreshes to <i>local repos</i>.<br>'
+        'Default: auto')),
     )),
 
 ({'name': 'web', 'label': _('Web Server'), 'icon': 'proxy'}, (
@@ -713,6 +783,10 @@ INFO = (
           'while {1} refers to the first group and so on. If no {n} tokens'
           'are found in issue.link, the entire matched string is appended '
           'instead.')),
+    _fi(_('Mandatory Issue Reference'), 'tortoisehg.issue.linkmandatory', genBoolRBGroup,
+        _('When committing, require that a reference to an issue be specified.  '
+          'If enabled, the regex configured in \'Issue Regex\' must find a match '
+          'in the commit message.')),
     _fi(_('Issue Tracker Plugin'), 'tortoisehg.issue.bugtraqplugin',
         (genDeferredCombo, findIssueTrackerPlugins),
         _('Configures a COM IBugTraqProvider or IBugTrackProvider2 issue '
@@ -737,6 +811,26 @@ INFO = (
     _fi(_('Target People'), 'reviewboard.target_people', genEditCombo,
         _('A comma separated list of target people')),
     )),
+    
+({'name': 'kbfiles', 'label': _('Kiln Bfiles'), 'icon': 'kiln', 'extension': 'kbfiles'}, (
+    _fi(_('Patterns'), 'kilnbfiles.patterns', genEditCombo,
+        _('Files with names meeting the specified patterns will be automatically '
+          'added as bfiles')),
+    _fi(_('Size'), 'kilnbfiles.size', genEditCombo,
+        _('Files of at least the specified size (in megabytes) will be added as bfiles')),
+    _fi(_('System Cache'), 'kilnbfiles.systemcache', genPathBrowser,
+        _('Path to the directory where a system-wide cache of bfiles will be stored')),
+    )),
+
+({'name': 'largefiles', 'label': _('Largefiles'), 'icon': 'kiln', 'extension': 'largefiles'}, (
+    _fi(_('Patterns'), 'largefiles.patterns', genEditCombo,
+        _('Files with names meeting the specified patterns will be automatically '
+          'added as largefiles')),
+    _fi(_('Size'), 'largefiles.size', genEditCombo,
+        _('Files of at least the specified size (in megabytes) will be added as largefiles')),
+    _fi(_('System Cache'), 'largefiles.systemcache', genPathBrowser,
+        _('Path to the directory where a system-wide cache of largefiles will be stored')),
+    )),
 
 )
 
@@ -915,6 +1009,8 @@ class SettingsForm(QWidget):
 
         # add page items to treeview
         for meta, info in INFO:
+            if 'extension' in meta and not hasExtension(meta['extension']):
+                continue
             if isinstance(meta['icon'], str):
                 icon = qtlib.geticon(meta['icon'])
             else:
@@ -954,7 +1050,8 @@ class SettingsForm(QWidget):
                 self.applyChanges()
             elif ret == 2:
                 return
-        if qscilib.fileEditor(self.fn, foldable=True) == QDialog.Accepted:
+        if (qscilib.fileEditor(hglib.tounicode(self.fn), foldable=True)
+            == QDialog.Accepted):
             self.refresh()
 
     def refresh(self, *args):
