@@ -45,6 +45,11 @@ class UpdateDialog(QDialog):
         self.grid.addWidget(QLabel(_('Update to:')), 0, 0)
         self.grid.addWidget(combo, 0, 1)
 
+        # Give the combo box a minimum width that will ensure that the dialog is
+        # large enough to fit the additional progress bar that will appear when
+        # updating subrepositories.
+        combo.setMinimumWidth(450)
+
         if rev is None:
             rev = self.repo.dirstate.branch()
         else:
@@ -91,29 +96,33 @@ class UpdateDialog(QDialog):
         self.grid.addWidget(expander, row, 0, Qt.AlignLeft | Qt.AlignTop)
         self.grid.addLayout(self.optbox, row, 1)
 
+        self.verbose_chk = QCheckBox(_('List updated files (--verbose)'))
         self.discard_chk = QCheckBox(_('Discard local changes, no backup '
                                        '(-C/--clean)'))
         self.merge_chk = QCheckBox(_('Always merge (when possible)'))
         self.autoresolve_chk = QCheckBox(_('Automatically resolve merge conflicts '
                                            'where possible'))
         self.showlog_chk = QCheckBox(_('Always show command log'))
+        self.optbox.addWidget(self.verbose_chk)
         self.optbox.addWidget(self.discard_chk)
         self.optbox.addWidget(self.merge_chk)
         self.optbox.addWidget(self.autoresolve_chk)
         self.optbox.addWidget(self.showlog_chk)
 
+        s = QSettings()
+
         self.discard_chk.setChecked(bool(opts.get('clean')))
 
         #### Persisted Options
         self.merge_chk.setChecked(
             QSettings().value('update/merge', False).toBool())
-        
+
         self.autoresolve_chk.setChecked(
             repo.ui.configbool('tortoisehg', 'autoresolve', False) or
-                QSettings().value('update/autoresolve', False).toBool())
-        
-        self.showlog_chk.setChecked(
-            QSettings().value('update/showlog', False).toBool())
+                s.value('update/autoresolve', False).toBool())
+
+        self.showlog_chk.setChecked(s.value('update/showlog', False).toBool())
+        self.verbose_chk.setChecked(s.value('update/verbose', False).toBool())
 
         ## command widget
         self.cmd = cmdui.Widget(True, True, self)
@@ -143,8 +152,8 @@ class UpdateDialog(QDialog):
         box.addWidget(buttons)
 
         # signal handlers
-        self.rev_combo.editTextChanged.connect(lambda *a: self.update_info())
-        self.discard_chk.toggled.connect(lambda *a: self.update_info())
+        self.rev_combo.editTextChanged.connect(self.update_info)
+        self.discard_chk.toggled.connect(self.update_info)
 
         # dialog setting
         self.setLayout(box)
@@ -174,11 +183,12 @@ class UpdateDialog(QDialog):
             return False
 
     def saveSettings(self):
+        QSettings().setValue('update/verbose', self.verbose_chk.isChecked())
         QSettings().setValue('update/merge', self.merge_chk.isChecked())
         QSettings().setValue('update/autoresolve', self.autoresolve_chk.isChecked())
         QSettings().setValue('update/showlog', self.showlog_chk.isChecked())
 
-    def update_info(self):
+    def update_info(self, *args):
         self.p1_info.update(self.ctxs[0].node())
         merge = len(self.ctxs) == 2
         if merge:
@@ -202,7 +212,9 @@ class UpdateDialog(QDialog):
 
     def update(self):
         self.saveSettings()
-        cmdline = ['update', '--repository', self.repo.root, '--verbose']
+        cmdline = ['update', '--repository', self.repo.root]
+        if self.verbose_chk.isChecked():
+            cmdline += ['--verbose']
         cmdline += ['--config', 'ui.merge=internal:' +
                     (self.autoresolve_chk.isChecked() and 'merge' or 'fail')]
         rev = hglib.fromunicode(self.rev_combo.currentText())
